@@ -4,17 +4,18 @@ from . import dispatch, B, Numeric
 from .custom import tensorflow_register
 from ..custom import toeplitz_solve, s_toeplitz_solve, expm, s_expm, logm, s_logm
 from ..linear_algebra import _default_perm
+from ..util import resolve_axis
 
 __all__ = []
 
 
-@dispatch(Numeric, Numeric)
-def matmul(a, b, tr_a=False, tr_b=False):
+@dispatch
+def matmul(a: Numeric, b: Numeric, tr_a=False, tr_b=False):
     return tf.matmul(a, b, transpose_a=tr_a, transpose_b=tr_b)
 
 
-@dispatch(Numeric)
-def transpose(a, perm=None):
+@dispatch
+def transpose(a: Numeric, perm=None):
     # Correctly handle special cases.
     rank_a = B.rank(a)
     if rank_a == 0:
@@ -27,16 +28,18 @@ def transpose(a, perm=None):
     return tf.transpose(a, perm=perm)
 
 
-@dispatch(Numeric)
-def trace(a, axis1=0, axis2=1):
+@dispatch
+def trace(a: Numeric, axis1=-2, axis2=-1):
+    axis1 = resolve_axis(a, axis1)
+    axis2 = resolve_axis(a, axis2)
     perm = [i for i in range(B.rank(a)) if i not in [axis1, axis2]]
     perm += [axis1, axis2]
     a = tf.transpose(a, perm=perm)
     return tf.linalg.trace(a)
 
 
-@dispatch(Numeric, Numeric)
-def kron(a, b):
+@dispatch
+def kron(a: Numeric, b: Numeric):
     shape_a = B.shape(a)
     shape_b = B.shape(b)
 
@@ -50,53 +53,66 @@ def kron(a, b):
     return tf.reshape(a * b, tuple(x * y for x, y in zip(shape_a, shape_b)))
 
 
-@dispatch(Numeric)
-def svd(a, compute_uv=True):
+@dispatch
+def svd(a: Numeric, compute_uv=True):
     res = tf.linalg.svd(a, full_matrices=False, compute_uv=compute_uv)
     return (res[1], res[0], res[2]) if compute_uv else res
 
 
-@dispatch(Numeric, Numeric)
-def solve(a, b):
+@dispatch
+def solve(a: Numeric, b: Numeric):
     return tf.linalg.solve(a, b)
 
 
-@dispatch(Numeric)
-def inv(a):
+@dispatch
+def inv(a: Numeric):
     return tf.linalg.inv(a)
 
 
-@dispatch(Numeric)
-def det(a):
+@dispatch
+def det(a: Numeric):
     return tf.linalg.det(a)
 
 
-@dispatch(Numeric)
-def logdet(a):
+@dispatch
+def logdet(a: Numeric):
     return tf.linalg.logdet(a)
 
 
-f = tensorflow_register(expm, s_expm)
-dispatch(Numeric)(f)
-
-f = tensorflow_register(logm, s_logm)
-dispatch(Numeric)(f)
+_expm = tensorflow_register(expm, s_expm)
 
 
-@dispatch(Numeric)
-def cholesky(a):
+@dispatch
+def expm(a: Numeric):
+    return _expm(a)
+
+
+_logm = tensorflow_register(logm, s_logm)
+
+
+@dispatch
+def logm(a: Numeric):
+    return _logm(a)
+
+
+@dispatch
+def cholesky(a: Numeric):
     return tf.linalg.cholesky(a)
 
 
-@dispatch(Numeric, Numeric)
-def cholesky_solve(a, b):
+@dispatch
+def cholesky_solve(a: Numeric, b: Numeric):
     return tf.linalg.cholesky_solve(a, b)
 
 
-@dispatch(Numeric, Numeric)
-def triangular_solve(a, b, lower_a=True):
+@dispatch
+def triangular_solve(a: Numeric, b: Numeric, lower_a=True):
     return tf.linalg.triangular_solve(a, b, lower=lower_a)
 
 
-f = tensorflow_register(toeplitz_solve, s_toeplitz_solve)
-dispatch(Numeric, Numeric, Numeric)(f)
+_toeplitz_solve = tensorflow_register(toeplitz_solve, s_toeplitz_solve)
+
+
+@dispatch
+def toeplitz_solve(a: Numeric, b: Numeric, c: Numeric):
+    return _toeplitz_solve(a, b, c)
