@@ -85,9 +85,9 @@ def test_lazy_shape():
         assert isinstance(B.shape(a), tuple)
 
 
-def test_isscalar(check_lazy_shapes):
-    assert B.isscalar(1.0)
-    assert not B.isscalar(np.array([1.0]))
+def test_is_scalar(check_lazy_shapes):
+    assert B.is_scalar(1.0)
+    assert not B.is_scalar(np.array([1.0]))
 
 
 def test_expand_dims(check_lazy_shapes):
@@ -245,9 +245,14 @@ def test_take_indices_rank(check_lazy_shapes):
             B.take(a, [[0], [1]])
 
 
-def test_take_empty_list(check_lazy_shapes):
-    # Check empty list.
-    check_function(B.take, (Matrix(3, 4), Value([])), {"axis": Value(0, 1)})
+@pytest.mark.parametrize(
+    "indices_or_mask",
+    [[], [0, 2], [True, False, True], (), (0, 2), (True, False, True)],
+)
+def test_take_list_tuple(check_lazy_shapes, indices_or_mask):
+    check_function(
+        B.take, (Matrix(3, 3, 3), Value(indices_or_mask)), {"axis": Value(0, 1, 2)}
+    )
 
 
 def test_take_tf(check_lazy_shapes):
